@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -46,6 +46,9 @@ sub Run {
         Data => $SessionData{ProcessManagementScreensPath}
     );
 
+    # get parameter from web browser
+    my $GetParam = $Self->_GetParams();
+
     # get needed objects
     my $ConfigObject         = $Kernel::OM->Get('Kernel::Config');
     my $EntityObject         = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Entity');
@@ -63,6 +66,7 @@ sub Run {
         Owner       => 'OwnerID',
         PendingTime => 'PendingTime',
         Title       => 'Title',
+        Attachments => 'Attachments',
     };
 
     # add service and SLA fields, if option is activated in sysconfig.
@@ -94,6 +98,7 @@ sub Run {
         # do not show internal fields for process management
         next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementProcessID';
         next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementActivityID';
+        next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementAttachment';
 
         $AvailableFieldsList->{"DynamicField_$DynamicFieldName"} = $DynamicFieldName;
     }
@@ -120,26 +125,20 @@ sub Run {
         # get Activity Dialog data
         my $ActivityDialogData;
 
-        # get parameter from web browser
-        my $GetParam = $Self->_GetParams();
+        # set new configuration
+        $ActivityDialogData->{Name}     = $GetParam->{Name};
+        $ActivityDialogData->{EntityID} = $GetParam->{EntityID};
+        $ActivityDialogData->{Config}   = $GetParam->{Config};
+        my @GetParamFields = @{ $GetParam->{Config}->{Fields} };
 
-        # set new confguration
-        $ActivityDialogData->{Name}                       = $GetParam->{Name};
-        $ActivityDialogData->{EntityID}                   = $GetParam->{EntityID};
-        $ActivityDialogData->{Config}->{Interface}        = $GetParam->{Interface};
-        $ActivityDialogData->{Config}->{DescriptionShort} = $GetParam->{DescriptionShort};
-        $ActivityDialogData->{Config}->{DescriptionLong}  = $GetParam->{DescriptionLong};
-        $ActivityDialogData->{Config}->{Permission}       = $GetParam->{Permission};
-        $ActivityDialogData->{Config}->{RequiredLock}     = $GetParam->{RequiredLock} || 0;
-        $ActivityDialogData->{Config}->{SubmitAdviceText} = $GetParam->{SubmitAdviceText};
-        $ActivityDialogData->{Config}->{SubmitButtonText} = $GetParam->{SubmitButtonText};
-        $ActivityDialogData->{Config}->{Fields}           = {};
-        $ActivityDialogData->{Config}->{FieldOrder}       = [];
+        $ActivityDialogData->{Config}->{Fields}     = {};
+        $ActivityDialogData->{Config}->{FieldOrder} = [];
 
-        if ( IsArrayRefWithData( $GetParam->{Fields} ) ) {
+        if (@GetParamFields) {
 
             FIELD:
-            for my $FieldName ( @{ $GetParam->{Fields} } ) {
+            for my $FieldName (@GetParamFields) {
+
                 next FIELD if !$FieldName;
                 next FIELD if !$AvailableFieldsList->{$FieldName};
 
@@ -152,13 +151,14 @@ sub Run {
         }
 
         # add field detail config to fields
-        if ( IsHashRefWithData( $GetParam->{FieldDetails} ) ) {
+        if ( IsHashRefWithData( $GetParam->{Config}->{FieldDetails} ) ) {
             FIELDDETAIL:
-            for my $FieldDetail ( sort keys %{ $GetParam->{FieldDetails} } ) {
+            for my $FieldDetail ( sort keys %{ $GetParam->{Config}->{FieldDetails} } ) {
                 next FIELDDETAIL if !$FieldDetail;
                 next FIELDDETAIL if !$ActivityDialogData->{Config}->{Fields}->{$FieldDetail};
 
-                $ActivityDialogData->{Config}->{Fields}->{$FieldDetail} = $GetParam->{FieldDetails}->{$FieldDetail};
+                $ActivityDialogData->{Config}->{Fields}->{$FieldDetail}
+                    = $GetParam->{Config}->{FieldDetails}->{$FieldDetail};
             }
         }
 
@@ -183,7 +183,7 @@ sub Run {
             $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{DescriptionShort} ) {
+        if ( !$GetParam->{Config}->{DescriptionShort} ) {
 
             # add server error error class
             $Error{DescriptionShortServerError} = 'ServerError';
@@ -191,12 +191,12 @@ sub Run {
         }
 
         # check if permission exists
-        if ( defined $GetParam->{Permission} && $GetParam->{Permission} ne '' ) {
+        if ( defined $GetParam->{Config}->{Permission} && $GetParam->{Config}->{Permission} ne '' ) {
             my $PermissionList = $ConfigObject->Get('System::Permission');
 
             my %PermissionLookup = map { $_ => 1 } @{$PermissionList};
 
-            if ( !$PermissionLookup{ $GetParam->{Permission} } )
+            if ( !$PermissionLookup{ $GetParam->{Config}->{Permission} } )
             {
 
                 # add server error error class
@@ -205,12 +205,26 @@ sub Run {
         }
 
         # check if required lock exists
-        if ( $GetParam->{RequiredLock} && $GetParam->{RequiredLock} ne 1 ) {
+        if ( $GetParam->{Config}->{RequiredLock} && $GetParam->{Config}->{RequiredLock} ne 1 ) {
 
             # add server error error class
             $Error{RequiredLockServerError} = 'ServerError';
         }
 
+        if ( !$GetParam->{Config}->{Scope} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
+        if ( $GetParam->{Config}->{Scope} eq 'Process' && !$GetParam->{Config}->{ScopeEntityID} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
         # if there is an error return to edit screen
         if ( IsHashRefWithData( \%Error ) ) {
             return $Self->_ShowEdit(
@@ -375,26 +389,19 @@ sub Run {
         # get Activity Dialog Data
         my $ActivityDialogData;
 
-        # get parameter from web browser
-        my $GetParam = $Self->_GetParams();
+        # set new configuration
+        $ActivityDialogData->{Name}     = $GetParam->{Name};
+        $ActivityDialogData->{EntityID} = $GetParam->{EntityID};
+        $ActivityDialogData->{Config}   = $GetParam->{Config};
+        my @GetParamFields = @{ $GetParam->{Config}->{Fields} };
 
-        # set new confguration
-        $ActivityDialogData->{Name}                       = $GetParam->{Name};
-        $ActivityDialogData->{EntityID}                   = $GetParam->{EntityID};
-        $ActivityDialogData->{Config}->{Interface}        = $GetParam->{Interface};
-        $ActivityDialogData->{Config}->{DescriptionShort} = $GetParam->{DescriptionShort};
-        $ActivityDialogData->{Config}->{DescriptionLong}  = $GetParam->{DescriptionLong};
-        $ActivityDialogData->{Config}->{Permission}       = $GetParam->{Permission};
-        $ActivityDialogData->{Config}->{RequiredLock}     = $GetParam->{RequiredLock} || 0;
-        $ActivityDialogData->{Config}->{SubmitAdviceText} = $GetParam->{SubmitAdviceText};
-        $ActivityDialogData->{Config}->{SubmitButtonText} = $GetParam->{SubmitButtonText};
-        $ActivityDialogData->{Config}->{Fields}           = {};
-        $ActivityDialogData->{Config}->{FieldOrder}       = [];
+        $ActivityDialogData->{Config}->{Fields}     = {};
+        $ActivityDialogData->{Config}->{FieldOrder} = [];
 
-        if ( IsArrayRefWithData( $GetParam->{Fields} ) ) {
+        if (@GetParamFields) {
 
             FIELD:
-            for my $FieldName ( @{ $GetParam->{Fields} } ) {
+            for my $FieldName (@GetParamFields) {
                 next FIELD if !$FieldName;
                 next FIELD if !$AvailableFieldsList->{$FieldName};
 
@@ -407,13 +414,14 @@ sub Run {
         }
 
         # add field detail config to fields
-        if ( IsHashRefWithData( $GetParam->{FieldDetails} ) ) {
+        if ( IsHashRefWithData( $GetParam->{Config}->{FieldDetails} ) ) {
             FIELDDETAIL:
-            for my $FieldDetail ( sort keys %{ $GetParam->{FieldDetails} } ) {
+            for my $FieldDetail ( sort keys %{ $GetParam->{Config}->{FieldDetails} } ) {
                 next FIELDDETAIL if !$FieldDetail;
                 next FIELDDETAIL if !$ActivityDialogData->{Config}->{Fields}->{$FieldDetail};
 
-                $ActivityDialogData->{Config}->{Fields}->{$FieldDetail} = $GetParam->{FieldDetails}->{$FieldDetail};
+                $ActivityDialogData->{Config}->{Fields}->{$FieldDetail}
+                    = $GetParam->{Config}->{FieldDetails}->{$FieldDetail};
             }
         }
 
@@ -446,7 +454,7 @@ sub Run {
             $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{DescriptionShort} ) {
+        if ( !$GetParam->{Config}->{DescriptionShort} ) {
 
             # add server error error class
             $Error{DescriptionShortServerError} = 'ServerError';
@@ -454,13 +462,13 @@ sub Run {
         }
 
         # check if permission exists
-        if ( defined $GetParam->{Permission} && $GetParam->{Permission} ne '' ) {
+        if ( defined $GetParam->{Config}->{Permission} && $GetParam->{Config}->{Permission} ne '' ) {
 
             my $PermissionList = $ConfigObject->Get('System::Permission');
 
             my %PermissionLookup = map { $_ => 1 } @{$PermissionList};
 
-            if ( !$PermissionLookup{ $GetParam->{Permission} } )
+            if ( !$PermissionLookup{ $GetParam->{Config}->{Permission} } )
             {
 
                 # add server error error class
@@ -469,7 +477,7 @@ sub Run {
         }
 
         # check if required lock exists
-        if ( $GetParam->{RequiredLock} && $GetParam->{RequiredLock} ne 1 ) {
+        if ( $GetParam->{Config}->{RequiredLock} && $GetParam->{Config}->{RequiredLock} ne 1 ) {
 
             # add server error error class
             $Error{RequiredLockServerError} = 'ServerError';
@@ -623,6 +631,10 @@ sub _ShowEdit {
 
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
+    # get parameter from web browser
+    my $GetParam = $Self->_GetParams();
+    $GetParam->{ProcessEntityID} ||= $Self->{ScreensPath}->[-1]->{ProcessEntityID};
+
     # check if last screen action is main screen
     if ( $Self->{ScreensPath}->[-1]->{Action} eq 'AdminProcessManagement' ) {
 
@@ -638,10 +650,11 @@ sub _ShowEdit {
         $LayoutObject->Block(
             Name => 'GoBack',
             Data => {
-                Action    => $Self->{ScreensPath}->[-1]->{Action}    || '',
-                Subaction => $Self->{ScreensPath}->[-1]->{Subaction} || '',
-                ID        => $Self->{ScreensPath}->[-1]->{ID}        || '',
-                EntityID  => $Self->{ScreensPath}->[-1]->{EntityID}  || '',
+                Action          => $Self->{ScreensPath}->[-1]->{Action}          || '',
+                Subaction       => $Self->{ScreensPath}->[-1]->{Subaction}       || '',
+                ID              => $Self->{ScreensPath}->[-1]->{ID}              || '',
+                EntityID        => $Self->{ScreensPath}->[-1]->{EntityID}        || '',
+                ProcessEntityID => $Self->{ScreensPath}->[-1]->{ProcessEntityID} || '',
             },
         );
     }
@@ -657,6 +670,7 @@ sub _ShowEdit {
         Owner       => 'OwnerID',
         PendingTime => 'PendingTime',
         Title       => 'Title',
+        Attachments => 'Attachments',
     };
 
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
@@ -690,6 +704,7 @@ sub _ShowEdit {
         # do not show internal fields for process management
         next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementProcessID';
         next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementActivityID';
+        next DYNAMICFIELD if $DynamicFieldName eq 'ProcessManagementAttachment';
 
         $AvailableFieldsList->{"DynamicField_$DynamicFieldName"} = $DynamicFieldName;
     }
@@ -930,6 +945,35 @@ sub _ShowEdit {
     $Param{SubmitAdviceText} = $Param{ActivityDialogData}->{Config}->{SubmitAdviceText};
     $Param{SubmitButtonText} = $Param{ActivityDialogData}->{Config}->{SubmitButtonText};
 
+    $Param{ScopeSelection} = $LayoutObject->BuildSelection(
+        Data => {
+            Global  => 'Global',
+            Process => 'Process',
+        },
+        Name           => 'Scope',
+        ID             => 'Scope',
+        SelectedID     => $Param{ActivityDialogData}->{Config}->{Scope} || 'Global',
+        Sort           => 'IndividualKey',
+        SortIndividual => [ 'Global', 'Process' ],
+        Translation    => 1,
+        Class          => 'Modernize W50pc ',
+    );
+
+    my $ProcessList = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Process')->ProcessList(
+        UserID      => 1,
+        UseEntities => 1,
+    );
+
+    $Param{ScopeEntityIDSelection} = $LayoutObject->BuildSelection(
+        Data        => $ProcessList,
+        Name        => 'ScopeEntityID',
+        ID          => 'ScopeEntityID',
+        SelectedID  => $Param{ActivityDialogData}->{Config}->{ScopeEntityID} // $GetParam->{ProcessEntityID},
+        Sort        => 'AlphanumericValue',
+        Translation => 1,
+        Class       => 'Modernize W50pc ',
+    );
+
     my $Output = $LayoutObject->Header(
         Value => $Param{Title},
         Type  => 'Small',
@@ -954,35 +998,43 @@ sub _GetParams {
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     # get parameters from web browser
+    for my $ParamName (qw( Name EntityID)) {
+        $GetParam->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
+    }
+
     for my $ParamName (
-        qw( Name EntityID Interface DescriptionShort DescriptionLong Permission RequiredLock SubmitAdviceText
-        SubmitButtonText )
+        qw( Interface DescriptionShort DescriptionLong Permission RequiredLock Scope ScopeEntityID SubmitAdviceText
+        SubmitButtonText ProcessEntityID)
         )
     {
-        $GetParam->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
+        $GetParam->{Config}->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
+    }
+    $GetParam->{Config}->{Scope} //= 'Global';
+    if ( $GetParam->{Config}->{Scope} eq 'Global' ) {
+        delete $GetParam->{Config}->{ScopeEntityID};
     }
 
     my $Fields     = $ParamObject->GetParam( Param => 'Fields' ) || '';
     my $JSONObject = $Kernel::OM->Get('Kernel::System::JSON');
 
     if ($Fields) {
-        $GetParam->{Fields} = $JSONObject->Decode(
+        $GetParam->{Config}->{Fields} = $JSONObject->Decode(
             Data => $Fields,
         );
     }
     else {
-        $GetParam->{Fields} = '';
+        $GetParam->{Config}->{Fields} = '';
     }
 
     my $FieldDetails = $ParamObject->GetParam( Param => 'FieldDetails' ) || '';
 
     if ($FieldDetails) {
-        $GetParam->{FieldDetails} = $JSONObject->Decode(
+        $GetParam->{Config}->{FieldDetails} = $JSONObject->Decode(
             Data => $FieldDetails,
         );
     }
     else {
-        $GetParam->{FieldDetails} = '';
+        $GetParam->{Config}->{FieldDetails} = '';
     }
 
     return $GetParam;
@@ -1028,10 +1080,11 @@ sub _PushSessionScreen {
 
     # add screen to the screen path
     push @{ $Self->{ScreensPath} }, {
-        Action    => $Self->{Action} || '',
-        Subaction => $Param{Subaction},
-        ID        => $Param{ID},
-        EntityID  => $Param{EntityID},
+        Action          => $Self->{Action} || '',
+        Subaction       => $Param{Subaction},
+        ID              => $Param{ID},
+        EntityID        => $Param{EntityID},
+        ProcessEntityID => $Param{ProcessEntityID},
     };
 
     # convert screens path to string (JSON)
